#include <Wire.h>

#define CTRL_REG1 0x20
#define CTRL_REG2 0x21
#define CTRL_REG3 0x22
#define CTRL_REG4 0x23

int Addr = 105;                             // I2C address of the L3G4200D gyro
int x, y, z;

void setup(){
  Wire.begin();
  Serial.begin(9600);
  writeI2C(CTRL_REG1, 0x1F);                // Turn on all axes, disable power down
  writeI2C(CTRL_REG3, 0x08);                // Enable control ready signal
  writeI2C(CTRL_REG4, 0x80);                // Set scale (500 deg/sec)
  delay(100);                               // Wait to synchronize 
}

void loop(){
  getGyroValues();                         // Get new values
  Serial.print("Raw X:");  Serial.print(x / 114);  // Divide by 114 reduces noise
  Serial.print(" Raw Y:"); Serial.print(y / 114);
  Serial.print(" Raw Z:"); Serial.println(z / 114);
  delay(500);                              // Short delay between reads
}

void getGyroValues () {
  byte MSB, LSB;

  MSB = readI2C(0x29);
  LSB = readI2C(0x28);
  x = ((MSB << 8) | LSB);

  MSB = readI2C(0x2B);
  LSB = readI2C(0x2A);
  y = ((MSB << 8) | LSB);

  MSB = readI2C(0x2D);
  LSB = readI2C(0x2C);
  z = ((MSB << 8) | LSB);
}

int readI2C (byte regAddr) {
    Wire.beginTransmission(Addr);
    Wire.send(regAddr);                     // Register address to read
    Wire.endTransmission();                 // Terminate request
    Wire.requestFrom(Addr, 1);              // Read a byte
    while(!Wire.available()) { };           // Wait for receipt
    return(Wire.receive());                 // Get result
}

void writeI2C (byte regAddr, byte val) {
    Wire.beginTransmission(Addr);           // Begin transmission 
    Wire.send(regAddr);                     // Open communications
    Wire.send(val);                         // Send value
    Wire.endTransmission();                 // End transmission
}
